/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'sl', {
	button: 'Vstavi odsek kode',
	codeContents: 'Koda vsebina',
	emptySnippetError: 'Odrezek kode ne more biti prazen.',
	language: 'Jezik',
	title: 'Odrezek kode',
	pathName: 'odrezek kode'
} );
